.. _glossary:

##########
 Glossary
##########

.. glossary::

   admin class   
     EntityAdmin subclass that controls how a :term:`Model` is displayed

   CAMELOT_ART_DIRECTORY
     todo

   delegate
     Used to display and edit data from a model. PyQt terminology.

   editor
     todo

   EntityAdmin
     todo

   entity
     todo

   fixture
     todo

   GUI
     Graphical User Interface.
     
   manage
     todo

   model
     A table in a database.

   PTC
     todo

   section
     Logical and graphical grouping of Models. Graphically displayed in the
     Camelot application left navigation pane.

   SQLAlchemy
     Powerful Python Object Relational Mapper.

   thread
     todo
   
   URI
     Uniform Resource Identifier
